@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-09-17'; # DATE
-our $VERSION = '1.31'; # VERSION
+our $DATE = '2015-09-18'; # DATE
+our $VERSION = '1.32'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -449,7 +449,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.31 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-09-17.
+This document describes version 1.32 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-09-18.
 
 =head1 SYNOPSIS
 
@@ -553,11 +553,12 @@ Automatic tab completion support:
  % complete -C gen-random-num gen-random-num
  % gen-random-num --mi<tab>
 
-See the manual for details on other available features (subcommands, automatic
-formatting of data structures, automatic schema validation, dry-run mode,
-automatic POD generation, remote function support, automatic CLI generation,
-automatic --version, automatic HTTP API, undo/transactions, configurable output
-format, logging, progress bar, colors/Unicode, and more).
+See L<Perinci::CmdLine::Manual> for details on other available features
+(subcommands, automatic formatting of data structures, automatic schema
+validation, dry-run mode, automatic POD generation, remote function support,
+automatic CLI generation, automatic --version, automatic HTTP API,
+undo/transactions, configurable output format, logging, progress bar,
+colors/Unicode, and more).
 
 =head1 DESCRIPTION
 
@@ -653,7 +654,11 @@ any newline to keep the data being printed unmodified.
 
 =head1 SEE ALSO
 
-L<Perinci::CmdLine::Any>, L<Perinci::CmdLine::Classic>
+L<Perinci::CmdLine::Any>
+
+L<Perinci::CmdLine::Classic>
+
+L<Perinci::CmdLine::Inline>
 
 =head1 HOMEPAGE
 
